%define anolis_release 1

%bcond_without libssh2

Name:           libgit2
Version:        1.7.2
Release:        %{anolis_release}%{?dist}
Summary:        C implementation of the Git core methods as a library with a solid API
License:        GPLv2 with exceptions
URL:            https://libgit2.org/
Source0:        https://github.com/%{name}/%{name}/archive/refs/tags/v%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  cmake >= 3.5.1
BuildRequires:  ninja-build
BuildRequires:  http-parser-devel
BuildRequires:  krb5-devel
BuildRequires:  libcurl-devel
%if %{with libssh2}
BuildRequires:  libssh2-devel
%endif
BuildRequires:  openssl-devel
BuildRequires:  pcre2-devel
BuildRequires:  python3
BuildRequires:  zlib-devel
Provides:       bundled(libxdiff)
Obsoletes:      libgit2_1.3 < 1.3.2-3
Obsoletes:      libgit2_1.4 < 1.4.6-3

%description
libgit2 is a portable, pure C implementation of the Git core methods
provided as a re-entrant linkable library with a solid API, allowing
you to write native speed custom Git applications in any language
with bindings.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{EVR}
Obsoletes:      libgit2_1.3-devel < 1.3.2-3
Obsoletes:      libgit2_1.4-devel < 1.4.6-3

%description    devel
This package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:   Doc files for %{name}
Requires:  %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
This package contains documentation for %{name}.

%prep
%autosetup -p1 -n libgit2-%{version}

# Remove VCS files from examples
find examples -name ".gitignore" -delete -print

# Don't run "online" tests
sed -i '/-sonline/s/^/#/' tests/libgit2/CMakeLists.txt

# Remove bundled libraries (except libxdiff)
pushd deps
find . -maxdepth 1 -not -name xdiff -exec rm -rf {} ';'
popd

%build
%cmake \
  -GNinja \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DREGEX_BACKEND=pcre2 \
  -DBUILD_CLI=OFF \
  -DUSE_HTTP_PARSER=system \
  -DUSE_SHA1=HTTPS \
  -DUSE_HTTPS=OpenSSL \
  -DUSE_NTLMCLIENT=OFF \
%if %{with libssh2}
  -DUSE_SSH=ON \
%else
  -DUSE_SSH=OFF \
%endif
  %{nil}
%cmake_build

%install
%cmake_install

%generate_compatibility_deps

%check
%ctest

%files
%license COPYING
%{_libdir}/libgit2.so.1.7*
%dir %{abidir}
%{abidir}/libgit2*.dump

%files devel
%{_libdir}/libgit2.so
%{_libdir}/pkgconfig/libgit2.pc
%{_includedir}/git2.h
%{_includedir}/git2/

%files doc
%doc AUTHORS docs examples README.md

%changelog
* Tue Mar 26 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.7.2-1
- update to 1.7.2

* Sun Aug 27 2023 Funda Wang <fundawang@yeah.net> - 1.6.4-1
- New version 1.6.4

* Mon Apr 10 2023 Kun(llfl) <llfl@linux.alibaba.com> - 1.5.1-2
- optimize spec file
- add patch to skip online tests

* Sun Jan 22 2023 Funda Wang <fundawang@yeah.net> - 1.5.1-1
- New version 1.5.1

* Mon Dec 19 2022 Funda Wang <fundawang@yeah.net> - 1.5.0-1
- New version 1.5.0

* Tue Jul 12 2022 happy_orange <songnannan@linux.alibaba.com> - 1.3.1-1
- Init pcakage from upstream
